@@ -16,11 +16,11 @@
 #include <locale.h>
 
 #include <X11/extensions/Xfixes.h>
-#include <clutter/x11/clutter-x11.h>
 #include <gdk/gdkx.h>
 #include <gio/gio.h>
 #include <girepository.h>
 #include <meta/meta-backend.h>
+#include <meta/meta-context.h>
 #include <meta/display.h>
 #include <meta/util.h>
 #include <meta/meta-shaped-texture.h>
@@ -53,6 +53,7 @@ struct _ShellGlobal {
   ClutterStage *stage;
 
   MetaBackend *backend;
+  MetaContext *meta_context;
   MetaDisplay *meta_display;
   MetaWorkspaceManager *workspace_manager;
   Display *xdisplay;
@@ -92,6 +93,7 @@ enum {
 
   PROP_SESSION_MODE,
   PROP_BACKEND,
+  PROP_CONTEXT,
   PROP_DISPLAY,
   PROP_WORKSPACE_MANAGER,
   PROP_SCREEN_WIDTH,
@@ -235,6 +237,9 @@ shell_global_get_property(GObject         *object,
     case PROP_BACKEND:
       g_value_set_object (value, global->backend);
       break;
+    case PROP_CONTEXT:
+      g_value_set_object (value, global->meta_context);
+      break;
     case PROP_DISPLAY:
       g_value_set_object (value, global->meta_display);
       break;
@@ -514,6 +519,13 @@ shell_global_class_init (ShellGlobalClass *klass)
                                                         "MetaBackend object",
                                                         META_TYPE_BACKEND,
                                                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+  g_object_class_install_property (gobject_class,
+                                   PROP_CONTEXT,
+                                   g_param_spec_object ("context",
+                                                        "Context",
+                                                        "MetaContext object",
+                                                        META_TYPE_CONTEXT,
+                                                        G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gobject_class,
                                    PROP_DISPLAY,
                                    g_param_spec_object ("display",
@@ -996,6 +1008,7 @@ _shell_global_set_plugin (ShellGlobal *global,
 
   display = meta_plugin_get_display (plugin);
   global->meta_display = display;
+  global->meta_context = meta_display_get_context (display);
   global->workspace_manager = meta_display_get_workspace_manager (display);
 
   global->stage = CLUTTER_STAGE (meta_get_stage_for_display (display));
@@ -1445,6 +1458,11 @@ shell_global_app_launched_cb (GAppLaunchContext *context,
   if (!g_variant_lookup (platform_data, "pid", "i", &pid))
     return;
 
+  /* If pid == 0 the application was launched through D-Bus
+   * activation, therefore it's already in its own unit */
+  if (pid == 0)
+    return;
+
   app_name = g_app_info_get_id (info);
   if (app_name == NULL)
     app_name = g_app_info_get_executable (info);
