@@ -2,8 +2,7 @@
 
 imports.gi.versions.Gtk = '3.0';
 
-const Gtk = imports.gi.Gtk;
-const Mainloop = imports.mainloop;
+const { GLib, Gtk } = imports.gi;
 
 function nextTitle() {
     let length = Math.random() * 20;
@@ -21,10 +20,12 @@ function main() {
     Gtk.init(null);
 
     let win = new Gtk.Window({ title: nextTitle() });
-    win.connect('destroy', Gtk.main_quit);
+    win.connect('destroy', () => {
+        Gtk.main_quit();
+    });
     win.present();
 
-    Mainloop.timeout_add(5000, function() {
+    GLib.timeout_add(GLib.PRIORITY_DEFAULT, 5000, function() {
         win.title = nextTitle();
         return true;
     });
